
import java.applet.Applet;
import java.awt.*;
import java.awt.event.*;

/**
 * Differences from version 10: now the buttons do something.  To make this work,
 * we need some code to be executed whenever they are pressed.  This code is the
 * "actionPerformed" method.  We also need to TELL the Buttons what object should
 * be informed when they are pressed, using the "addActionListener" method, which
 * takes in an ActionListener object.  ActionListener is actually a predefined
 * interface which simply means "any object that has an actionPerformed method";
 * since MyApplet now has such a method, it's entitled to claim that it implements
 * ActionListener, and thus "this" can be passed into "addActionListener".
 * Incidentally, I've also taken out the "repaint()" call in "paint()".
 *
 * @author Stephen Bloch 
 * @version 24 Nov 2000, version 11
 */
public class MyApplet extends Applet implements ActionListener
{

	// Instance variables
	int ballX, ballY;
	int ballDX = 10;
	int ballDY = 5;
	int counter = 1;
	Label firstLabel, secondLabel;
	TextField theTextField;
	Button thisButton, thatButton, theOtherButton;

	/**
	 * Called by the browser or applet viewer to inform this Applet that it
	 * has been loaded into the system. It is always called before the first 
	 * time that the start method is called.
	 */
	public void init()
	{
		// provide any initialisation necessary for your Applet
		ballX = 30;
		ballY = 60;

		String message = this.getParameter ("message");
		ballDX = Integer.parseInt (this.getParameter ("dx"));
		ballDY = Integer.parseInt (this.getParameter ("dy"));

		secondLabel = new Label("                              "); // room for 30 characters
		firstLabel = new Label(message);
		theTextField = new TextField("Your name here");
		thisButton = new Button ("This Button");
		thatButton = new Button ("That Button");
		theOtherButton = new Button ("The other Button");

		thisButton.addActionListener (this);
		thatButton.addActionListener (this);
		theOtherButton.addActionListener (this);
		// Note: they don't need to all have the same object as listener.
		// If they do, its actionPerformed() method needs to check which one
		// triggered the event.

		this.add (firstLabel);
		this.add (secondLabel);
		this.add (theTextField);
		this.add (thisButton);
		this.add (thatButton);
		this.add (theOtherButton);
	}

	/**
	 * This may be the most important method in your applet: Here, the 
	 * drawing of the applet gets done. "paint" gets called everytime the
	 * applet should be drawn on the screen. So put the code here that
	 * shows the applet.
	 *
	 * @param  g   the Graphics object for this applet
	 */
	public void paint(Graphics g)
	{
		// simple text displayed on applet
		g.setColor(Color.white);
		g.fillRect(0, 0, 3000, 3000);
		g.setColor(Color.red);
		secondLabel.setText ("paint() call #" + counter++);
		g.fillOval (ballX,ballY,80,50);
		ballX += ballDX;
		ballY += ballDY;
		// repaint ();
		// NOTE: this is NOT the "approved" way to animate a picture,
		// but it's the easiest to demonstrate on Day 1.
	}

	public String[][] getParameterInfo () {
		final String[][] answer =
				{{"message","String","a message to be printed on the screen"},
				 {"dx","integer","how fast the ball should move in the x direction"},
				 {"dy","integer","how fast the ball should move in the y direction"}};
		return answer;
		}

	public void actionPerformed (ActionEvent e) {
		// respond to button press
		if (e.getSource() == thisButton) {
			firstLabel.setText("This!");
			}
		else if (e.getSource() == thatButton) {
			firstLabel.setText("That!");
			}
		else if (e.getSource() == theOtherButton) {
			if (e.getActionCommand().equals("The other Button")) {
				theOtherButton.setLabel ("Use text field");
				firstLabel.setText("The other!");
				}
			else {
				firstLabel.setText(theTextField.getText());
				}
			}
		else {
			firstLabel.setText("This can't happen!");
			}
		}
}
